function rho = ec_F(F, df)
% function rho = ec_F(F, df)
%
% Compute the Euler characterisic equation values for the given
% F-statistics.
%
% Arguments:
%       F - A vector of F-statistics of length k.
%      df - The degrees of freedom of the F-distribution.
%
% Returns:
%       rho - A 4-by-k matrix of Euler characteristic values
%
% Written by Brian Booth <brian.booth@uantwerpen.be>, July 28, 2016
%


    F = F(:)';
    
    k = df(1);
    v = df(2);
    a = (4*log(2))/(2*pi);
    b = gammaln(v/2) + gammaln(k/2);

    rho = zeros(4, numel(F));
    rho(1,:) = 1 - fcdf(F, df(1), df(2));
    rho(2,:) = a^(1/2)*exp(gammaln((v+k-1)/2)-b)*2^(1/2) ...
        *(k*F/v).^(1/2*(k-1)).*(1+k*F/v).^(-1/2*(v+k-2));
    rho(3,:) = a*exp(gammaln((v+k-2)/2)-b)*(k*F/v).^(1/2*(k-2)) ...
        .*(1+k*F/v).^(-1/2*(v+k-2)).*((v-1)*k*F/v-(k-1));
    rho(4,:) = a^(3/2)*exp(gammaln((v+k-3)/2)-b)...
        *2^(-1/2)*(k*F/v).^(1/2*(k-3)).*(1+k*F/v).^(-1/2*(v+k-2)) ...
        .*((v-1)*(v-2)*(k*F/v).^2-(2*v*k-v-k-1)*(k*F/v)+(k-1)*(k-2));
