function rho = ec_t(t, df)
% function rho = ec_t(t, df)
%
% Compute the Euler characterisic equation values for the given
% t-statistics.
%
% Arguments:
%       t - A vector of t-statistics of length k.
%      df - The degree of freedom of the t-distribution.
%
% Returns:
%       rho - A 4-by-k matrix of Euler characteristic values
%
% Written by Brian Booth <brian.booth@uantwerpen.be>, July 28, 2016
%


    t = t(:)';
    
    v = df;
    a = 4*log(2);
    b = exp(gammaln((v+1)/2) - gammaln(v/2));
    c = (1+t.^2/v).^((1-v)/2);

    rho = zeros(4, numel(t));
    rho(1,:) = 1 - tcdf(t,v);
    rho(2,:) = a^(1/2)/(2*pi)*c;
    rho(3,:) = a/((2*pi)^(3/2))*c.*t/((v/2)^(1/2))*b;
    rho(4,:) = a^(3/2)/((2*pi)^2)*c.*((v-1)*(t.^2)/v - 1);
