function rho = ec_z(z)
% function rho = ec_z(z)
%
% Compute the Euler characterisic equation values for the given
% z-scores.
%
% Arguments:
%       z - A vector of z-scores of length k.
%
% Returns:
%       rho - A 4-by-k matrix of Euler characteristic values
%
% Written by Brian Booth <brian.booth@uantwerpen.be>, July 28, 2016
%

    a = 4*log(2);
    b = exp(-0.5 * (z .^ 2));
    z = z(:)';

    rho = zeros(4, numel(z));
    rho(1,:) = 1 - normcdf(z);
    rho(2,:) = (a.^(1/2) / (2*pi)) * b;
    rho(3,:) = (a / ((2*pi)^(3/2))) * b .* z;
    rho(4,:) = (a.^(3/2) / ((2*pi)^2)) * b .* (z.^2 - 1);

    