function [reg_img, disp_field] = pairwise_deform_register(fixed_img, ...
                                                  moving_img)
% function [reg_img, disp_field] = pairwise_deform_register(fixed_img, ...
%                                                 moving_img)
%
% Register the given moving image to the given fixed image using a
% Demons deformable image registration. Use the example parameters
% given on the mathworks website to control the optimization.
%
% Arguments:
%       - fixed_img: The fixed image that we will register to.
%       - moving_img: The moving image that will be registered.
%
% Returns:
%       - reg_img: The registered moving image
%       - disp_field: The displacement field representing the
%                     deformation.
%
% Written by Brian Booth <Brian.Booth@uantwerpen.be>, January 6th, 2016
%

    % demons = images.registration.internal.MultiResolutionDemons2D( ...
    %                                                   moving_img, ...
    %                                                   fixed_img, ...
    %                                                   1, 3);
    % demons = runMultiResolutionDemons(demons, [100 100 100], 3);
    %
    % disp_field = demons.D;
    disp_field = demons_register(fixed_img, moving_img);
    
    reg_img = [];
    

function [demons, userCancelled] = runMultiResolutionDemons(demons, ...
                                                      numIterations, ...
                                                      pyramidLevels)

    for pyramidLevel = 1:pyramidLevels
                
        demons = demons.moveToPyramidLevel(pyramidLevel);
                   
        for n = 1:numIterations(pyramidLevel)
            demons = demons.iterate(1);
        end
    
    end