function R = resels_2D(maskIM, FWHM)
% function R = resels_2D(maskIM, FWHM)
%
% Copmute the number of resels in each dimension of the 2D binary
% image provided.
%
% Arguments:
%       maskIM - A 2D binary image
%         FWHM - Image smoothness defined as a full width at
%                half-max value.
%
% Returns:
%       R - A 4-vector containing the 0D, 1D, 2D and 3D resel counts.
%
% Written by Brian Booth <brian.booth@uantwerpen.be>, July 28, 2016
%

    ex = 0;
    ey = 0;
    f = 0;
    p = 0;
    
    for ii = 2:size(maskIM,1),
        for jj = 2:size(maskIM,2),
            
            if maskIM(ii,jj),
                p = p + 1;
                
                if maskIM(ii-1,jj),
                    ex = ex + 1;
                end
                
                if maskIM(ii,jj-1),
                    ey = ey + 1;
                end
                
                if maskIM(ii-1,jj) & maskIM(ii-1,jj-1) & ...
                        maskIM(ii,jj-1),
                    f = f + 1;
                end
            end
            
        end
    end

    R = zeros(1,4);
    R(1) = p - (ex + ey) + f;
    R(2) = (ex + ey - 2*f) / FWHM;
    R(3) = f / (FWHM.^2);
    R(4) = 0;