function R = resels_3D(maskIM, FWHM)
% function R = resels_3D(maskIM, FWHM)
%
% Copmute the number of resels in each dimension of the 3D binary
% image provided.
%
% Arguments:
%       maskIM - A 3D binary image
%         FWHM - Image smoothness defined as a full width at
%                half-max value.
%
% Returns:
%       R - A 4-vector containing the 0D, 1D, 2D, and 3D resel counts.
%
% Written by Brian Booth <brian.booth@uantwerpen.be>, July 28, 2016
%

    ex = 0;
    ey = 0;
    ez = 0;
    fxy = 0;
    fxz = 0;
    fyz = 0;
    c = 0;
    p = 0;
    
    for ii = 2:size(maskIM,1),
        for jj = 2:size(maskIM,2),
            for kk = 2:size(maskIM,3),
            
                if maskIM(ii,jj,kk),
                    p = p + 1;
                
                    if maskIM(ii-1,jj,kk),
                        ex = ex + 1;
                    end
                
                    if maskIM(ii,jj-1,kk),
                        ey = ey + 1;
                    end
                
                    if maskIM(ii,jj,kk-1),
                        ez = ez + 1;
                    end
                    
                    if maskIM(ii-1,jj,kk) & maskIM(ii-1,jj-1,kk) & ...
                            maskIM(ii,jj-1,kk),
                        fxy = fxy + 1;
                    end
                    
                    if maskIM(ii-1,jj,kk) & maskIM(ii-1,jj,kk-1) & ...
                            maskIM(ii,jj,kk-1),
                        fxz = fxz + 1;
                    end

                    if maskIM(ii,jj-1,kk) & maskIM(ii,jj-1,kk-1) & ...
                            maskIM(ii,jj,kk-1),
                        fyz = fyz + 1;
                    end
                    
                    if maskIM(ii,jj,kk-1) & maskIM(ii,jj-1,kk) & ...
                            maskIM(ii-1,jj,kk) & maskIM(ii,jj-1,kk-1) & ...
                            maskIM(ii-1,jj-1,kk) & maskIM(ii-1,jj,kk-1) & ...
                            maskIM(ii-1,jj-1,kk-1),
                        c = c + 1;
                    end
                end 
                
            end
        end
    end
    
    R = zeros(1,4);
    R(1) = p - (ex + ey + ez) + (fxy + fxz + fyz) - c;
    R(2) = (ex - fxy - fxz + c) / FWHM + ...
           (ey - fxy - fyz + c) / FWHM + ...
           (ez - fxz - fyz + c) / FWHM;
    R(3) = (fxy - c) / (FWHM.^2) + ...
           (fxz - c) / (FWHM.^2) + ...
           (fyz - c) / (FWHM.^2);
    R(4) = c / (FWHM.^3);
    