function new_img = time_warp_cont(img, time_map)
% function new_img = time_warp_cont(img, time_map)
%
% Apply a continuous dynamic time warping correspondance to 
% the given 2D+time image.
%
% Arguments:
%      - img: The image to apply the time warp to.
%      - time_map: The frame correspondance map to apply to the
%                  image.
%
% Returns:
%      - new_img: The time warped image.
%
% Written by Brian Booth <Brian.Booth@uantwerpen.be>, February 2, 2016
%


    % Remove duplicate frames before interpolating by averaging their 
    % mapping
    new_map = zeros(max(time_map(:,1)), 2);
    for ii = 1:size(time_map,1),
        new_map(time_map(ii,1), 1) = new_map(time_map(ii,1),1) + 1;
        new_map(time_map(ii,1), 2) = new_map(time_map(ii,1),2) + ...
            time_map(ii,2);
    end
    new_map(:,2) = new_map(:,2) ./ new_map(:,1);
    new_map(:,1) = [1:size(new_map,1)]';
    
    vec_img = reshape(img, [size(img,1)*size(img,2) size(img,3)]);
    resampled_img = interp1(1:size(img,3), vec_img', new_map(:,2), ...
                            'pchip', 0);
    
    new_img = reshape(resampled_img', [size(img,1) size(img,2) ...
                        max(new_map(:,1))]); 
    new_img = max(0, real(new_img));