function [avg_left, avg_right] = tree_mean_unbias(subject_imgs)
% function [avg_left, avg_right] = tree_mean_unbias(subject_imgs)
%
% Compute an unbiased mean image by breaking up the image set into
% equal parts, creating means for each part, then creating an
% unbiased mean image from the unbiased mean images of each part.
%
% Arguments:
%     - subject_imgs: The plantar pressure images to make an
%                     unbiased mean out of.
%
% Returns:
%     - left_avg: The unbiased average of the left footprints.
%     - right_avg: The unbiased average of the right footprints.
%
% Written by Brian Booth <brian.booth@uantwerpen.be>, January 19, 2017
%

    N = size(subject_imgs,1);
    k = ceil(N / 50);
    n = ceil(N / k);
    
    if k == 1,
        [avg_left, avg_right] = make_unbiased_mean_sb(...
            subject_imgs, 'peak');
        return;
    end
    
    avg_imgs = cell(k, 2);
    for ii = 1:k,
        sid = (ii-1)*n + 1;
        eid = min(ii*n, N);
        [avg_imgs{ii,1}, avg_imgs{ii,2}] = make_unbiased_mean_sb(...
            subject_imgs(sid:eid,:), 'peak');
    end
    
    % Check if the training set has both feet
    k = 0;
    for ii = 1:size(avg_imgs,1),
        k = k + numel(avg_imgs{ii,2});
        
        if k > 0,
            break;
        end
    end
    
    if k == 0,
        avg_imgs = avg_imgs(:,1);
    end
    
    [avg_left, avg_right] = tree_mean_unbias(avg_imgs);
    