function predicted_img = predict_peak_pressures(demographics, models)
% function predicted_img = predict_peak_pressures(demographics, models)
%
% Given the demographics of of an individual - specifically their
% age, sex, height, weight, and shoe size - predict the peak
% pressure image for that individual using the statistical model
% defined by PAPPI.
%
% Inputs:
%    - demographics: A 5x1 vector containing, in order, the
%                    following demographic information for the
%                    individual whose peak pressures you want to
%                    predict:
%                     * age (in years)
%                     * sex (0 for female, 1 for male)
%                     * weight (in kilograms)
%                     * height (in centimeters)
%                     * shoe size (in the EU scale)
%    - models: A MATLAB structure containing the PAPPI statistical
%              models built using the 'build_models' function in
%              this PAPPI software package.
%
% Outputs:
%    - predicted_img: The predicted peak pressure image for the
%                     individual with the given demographic
%                     characteristics. 
%
% Written by Brian Booth <brian.booth@uantwerpen.be>
%

  if ~exist('predict_img'),
      p = mfilename('fullpath');
      [dir,~,~] = fileparts(p);
      addpath([dir, filesep, 'helper_functions']);
  end

  [predicted_img, ~] = predict_img(models.weights, demographics, ...
                                   models.residual_std);